@@ -55,7 +55,7 @@ def kendall_tau(X: np.ndarray, method='A', n_jobs=os.cpu_count()) -> np.float64:
         for j in range(X.shape[0]):
             if np.all(X[q] < X[j]) or np.all(X[q] > X[j]):
                 score += 1
-            elif np.all(X[q] == X[j]):
+            elif np.any(X[q] == X[j]):
                 continue
             else:
                 score -= 1
@@ -63,7 +63,6 @@ def kendall_tau(X: np.ndarray, method='A', n_jobs=os.cpu_count()) -> np.float64:
 
     pool = ProcessPool(nodes=n_jobs)
     score = np.sum(pool.map(scorer, range(X.shape[0])))
-    pool.close()
 
     if method == 'A':
         return score / ((X.shape[0] **2 - X.shape[0]))
@@ -141,9 +140,8 @@ def grade_entropy(X: np.ndarray, n_jobs=os.cpu_count()) -> np.float64:
         return v
 
     pool = ProcessPool(nodes=n_jobs)
-    for i, v in enumerate(pool.imap(grade, range(X.shape[0]))):
+    for i, v in enumerate(pool.map(grade, range(X.shape[0]))):
         P[:, i] = v
-    pool.close()
 
     bins, counts = np.unique(np.sum(P, axis=0), return_counts=True)
     probs = counts / np.sum(counts)
